.. trident documentation master file, created by
   sphinx-quickstart on Sat May  9 14:04:30 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to trident's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. image:: images/trident_logo.png
   :width: 500px
   :scale: 50 %
   :alt: alternate text
   :align: left

#.  *Classify cancer using simulated data (Logistic Regression)*
     Quick Start:`Logistic Regression <quickstart.html>`_ with NumPy (:tridenttw:`source <quickstart>`)



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
